@@ -14,7 +14,6 @@ from playwright.sync_api import expect
 from univention.testing.browser.appcenter import AppCenter
 from univention.testing.browser.lib import UMCBrowserTest
 from univention.testing.browser.suggestion import AppCenterCacheTest
-from univention.testing.utils import package_installed
 
 
 def test_suggestion_category_is_shown(umc_browser_test: UMCBrowserTest, app_center_cache: AppCenterCacheTest):
@@ -24,15 +23,14 @@ def test_suggestion_category_is_shown(umc_browser_test: UMCBrowserTest, app_cent
     "v1": [{
         "condition": [],
         "candidates": [{
-            "id": "pkgdb",
+            "id": "owncloud",
             "mayNotBeInstalled": []
         }]
     }]
 }
 """,
     )
-    if package_installed('univention-pkgdb'):
-        return
+
     app_center = AppCenter(umc_browser_test)
     app_center.navigate()
 
